#ifndef NT2_INCLUDE_FUNCTIONS_ROOTS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ROOTS_HPP_INCLUDED

#include <nt2/polynom/include/functions/roots.hpp>

#endif
